小森林 夏秋篇 (豆瓣)
Description: 小森林 夏秋篇电影简介和剧情介绍,小森林 夏秋篇影评、图片、预告片、影讯、论坛、在线购票
Keywords: 小森林 夏秋篇,リトル・フォレスト 夏・秋,小森林 夏秋篇影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.117豆瓣电影Top250

# 小森林 夏秋篇 リトル・フォレスト 夏・秋 (2014)

导演: 森淳一
编剧: 森淳一 / 五十岚大介
主演: 桥本爱 / 三浦贵大 / 松冈茉优 / 温水洋一 / 桐岛加恋
类型: 剧情
制片国家/地区: 日本
语言: 日语
上映日期: 2014-08-30(日本)
片长: 111分钟
又名: 小森食光/夏秋篇(台) / Little Forest Summer & Autumn
IMDb: tt3474600
豆瓣评分
引用
9.0
406103人评价
5星
59.4%
4星
32.6%
3星
7.2%
2星
0.6%
1星
0.2%
好于 98% 剧情片
想看 看过
评价:
推荐

## 小森林 夏秋篇的剧情简介 · · · · · ·

平凡女孩市子（桥本爱 饰）自幼生长在位于日本东北地区的村庄小森。这里远离都市的喧嚣和浮躁，为青山绿水所环绕，俨然一个幽静怡然的世外桃源。村民们日出而作，日落而息，依靠一双勤劳的双手经营渺小却舒适的生活，与世无争。市子曾经前往东京闯荡，只不过她终究无法适应都市快节奏的步伐，最终回到了妈妈早已不在的老宅。童年时妈妈福子利用山川田野各种食材做出胡乱命名的美食，实心眼的市子在感叹受骗之余，也将美好的回忆留在了味蕾深处。仿佛遵循着母亲的步伐，她将对故乡的热爱融入了美食的烹制中。在朋友佑太（三浦贵大 饰）和吉子（松冈茉优 饰）的环绕下，享受着无忧无虑的人生……
本片根据五十岚大介的漫画改编。 ©豆瓣

## 小森林 夏秋篇的演职员 · · · · · · ( 全部 9 )

- 森淳一 导演
- 桥本爱 演员
- 三浦贵大 演员
- 松冈茉优 饰 吉子
- 温水洋一 演员
- 桐岛加恋 演员

## 小森林 夏秋篇的视频和图片 · · · · · · ( 预告片3 | 添加视频评论 | 图片2099 · 添加 )

## 小森林 夏秋篇的获奖情况 · · · · · · ( 全部 )

- 第2届豆瓣电影年度榜单
- 最受关注的非院线电影(提名)

- 第2届豆瓣电影年度榜单
- 评分最高的日本电影

- 第6届豆瓣电影鑫像奖
- 鑫豆单元 最佳日本电影(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  小森林 冬春篇

  一一

  重庆森林

  花样年华

  布达佩斯大饭店

  爱在黎明破晓前

  海街日记

  天使爱美丽

  海上钢琴师

  甜蜜蜜

我要写短评

## 小森林 夏秋篇的短评 · · · · · · ( 全部 108683 条 )

热门 / 最新 / 好友

### 8081 有用 南笙 看过 2015-06-04 14:03:41

那些静得只能听见呼吸的日子里，你明白孤独即生活。

### 1394 有用 朝阳区陆依萍 看过 2015-06-07 21:00:53

看着看着，突然觉得好难过....

### 1283 有用 嘟嘟熊之父 看过 2015-04-24 12:11:46

劳作令人无暇烦恼，片中的人物时而离凡世很远，时而又触手可及。我们有舌尖上的中国，通篇累述奉献、感恩，手艺传承和文化气节，却没人教导我们劳作本身的意义。一屋一田一人食，已是最令人羡慕的事。

### 882 有用 黄青蕉 看过 2016-01-20 11:45:31

桥本哥演出了吃货的本心，一边捧着小鸭子说好可爱下一秒就开始平心静气的磨刀嘴角含笑的杀鸭肢解，大写的帅。

### 504 有用 薇羅尼卡 看过 2015-05-14 17:37:18

人生在世，无非就是过日子，而如何能让过日子变的有滋有味，我想不到除了充实的劳动/工作+美味的食物更好的方式了。桥本爱不矫作真自然，让人心生欢喜宁静。也许中国需要等待很久很久之后，才能拍出这种气息的片子了。

> 更多短评 108683条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 小森林 夏秋篇的影评 · · · · · · ( 全部 1291 条 )

热门 / 最新 / 好友
党阿飞 2015-03-15 13:57:19

## 从不依靠，从不寻找

这篇影评可能有剧透

《小森林》系列是由漫画家五十岚大介的原作改编的电影，在日本国内30块银幕上同时公映，首周初登场观众满意度排名第七位。《小森林》分为“春、夏、秋、冬”四篇，分别独立制作为电影，陆续上映并斩获好评。目前在国内能看到的就是高清版《夏》和《秋》两部。有人评说它是“舌... (展开)
3729 139 209回应 收起
苏白 2015-04-25 14:12:58

## 关于悠太选择回到乡村的理由

昨晚刚和家人一起观看了这部电影，非常喜欢。在繁忙工作一天之后，本来身心疲惫，但看过电影后立刻被治愈了。本人留学日本6年有余，对日式小清新的画面和日本的生活环境自然比较熟悉。但留学期间主要是待在东京这座繁华的大都会，对日本的农村生活没有直接的体验。尤其这部电影... (展开)
1878 46 133回应 收起
sususlsz 2015-04-13 08:52:50

## 【完结-更新repo】这不是一篇影评而是一本食谱★送给和我一样的吃货们★咕~~(╯﹏╰)b

这不是一篇影评而是一本食谱★送给和我一样的吃货们★咕~~(╯﹏╰)b 写着写着就饿了 咕~~(╯﹏╰)b 【更新了糖水栗子的repo，来自@永烁星光之地 ，感谢！repo特别贴心哟~想尝试这道美味的亲们千万看完了再做哈~~~】 喵~冬春篇都写好啦~~~有需要的请移步：http://movie.douban.c... (展开)
1209 14 183回应 收起
公子猫 2015-04-12 13:09:27

## 少女种水稻的残酷生活

这篇影评可能有剧透

我非常赞赏小森林的精神，从少女一个人做完所有农活，到吃白菜也要去掉筋，全部都是非常努力、认真生活的精神。它根本不是一个风花雪月的小清新，虽然它在深山中，有风有花有四季。城市里的小清新们看了电影，对那样悠然生活的心向往之，想着山间的水流、树下的野果、风吹... (展开)
591 29 66回应 收起
李BOBO 2018-03-23 10:32:45

## 在日本乡下是一种怎样的生活？

与其说这是一篇观后感，不如说这是一篇游记。 2016年的那个夏天，我看了《小森林》，然后买了机票，在日本找了一个乡下住了3个月，一直呆到了2017年的冬天。 原本我以为《小森林》是一部浪漫主义的电影，后来我才发现，它其实上是一种写实的风格。 日本是亚洲最发达的国家之一... (展开)
418 20 58回应 收起
娘腿儿 2015-03-06 14:47:51

## 给木心送完肉的姑娘怎么下山

春暖人软，小娃背花娘笑靥。 放学回家路过大片青草地，小花儿开的鲜。摘颜色，每种颜色收集全，双肩书包朝前背，拉链敞开塞满花枝，一路喊叫”卖汉堡包，卖汉堡包”。回到家妈等在门外，院儿里种满草花，闭眼，吸气，阳光橘子味。 童年有伴，夏日里不知何为午睡。 大人的世界静... (展开)
228 25 23回应 收起
西凉茉 2018-05-15 20:05:19

## 让人感动的句子

这篇影评可能有剧透

1 ，小森好像沉睡在蒸汽下，土壤里的水蒸气，争先恐后地要散发出来。 2，柿子很顽强，又很脆弱。 3，幼年时代的习惯是很难改变的，幼年体验非常重要。 4，虽然语言不可信赖，不过用自己的身体感受到的就能相信。 5，做菜能看出人心——现在这就是我的心的颜色，吗？ 6，……要... (展开)
149 4 4回应 收起
一觉年华秋梦醉 2016-06-01 00:23:07

## 把自己当成市子，做一道夏日甜品

这是一部，多么著名的电影。周围稍微有些小资情怀的姑娘，都会跟我推荐。有人说，画面美到能让你忘了周围的钢筋水泥；有人说，作为吃货你必须要看；还有人说，这样的生活你也在过，去看看吧。 农田、村舍、植物、昆虫，画面里的一切，都是我们熟悉的，导演用不同的镜头，展现... (展开)
79 9 4回应 收起
小蛋蛋 2015-07-16 09:08:26

## 热爱生活应该是什么模样

夜晚的时候，站在灶台前，看着牛奶在奶锅里咕噜咕噜冒着泡，唯一的一盏小灯显得格外温暖；冬天的时候，隔着烤箱看到自己的蝴蝶酥一点一点起酥膨胀，心都跟着丰盈起来；夏日午后，端着小板凳翻拌着蒸熟的绿豆泥，看着绿豆糕慢慢成型，成就感满满......还有好多这样的时候，这些... (展开)
117 6 5回应 收起
蒙奇D 2015-03-16 22:40:36

## 悠然自得

小森， 是山腰浓浓的雾气， 是夜晚滴答的雨水， 是早晨冰凉的薄霜， 是门前皑皑的白雪； 小森， 是井边的蛙声， 是树上的蝉歌， 是窗棂的振翅， 是田间的鸟鸣； 小森， 是郁郁葱葱的树林， 是潺潺流淌的溪水， 是滚滚而去的麦浪， 是铺满落叶的山路； 小森， 是酸甜红透的番... (展开)
96 6 9回应 收起

> 更多影评 1291篇

添加新讨论

## 讨论区 · · · · · ·

这女的是不是情商低啊 | 来自他方天气渐凉 | 2 回应 | 2022-11-15 04:24:48
为什么没有男版的呢？ | 来自活豪 | 4 回应 | 2022-11-14 23:34:15
作为一个旅游爱好者和资深吃货，表示风景很一般，... | 来自星月映像 | 23 回应 | 2022-11-11 22:15:03
在哪能看小森林？ | 来自나비🦋🦋 | 2 回应 | 2022-11-10 03:32:44
所以女主和她学弟是那啥了么？ | 来自倚石听涛 | 91 回应 | 2022-11-07 20:31:03

> 去这部影片的讨论区（全部129条）

## 关于《小森林 夏秋篇》的问题 · · · · · · ( 全部75个 )

- 觉得桥本妹子好舒服啊！！国内有人能演出这感觉吗？ 49人回答
- 女人会因为摘不到一个果子就和男票分手吗？ 12人回答

> 全部75个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 【♨大未的私房菜馆♨】 (洋)
- 治愈系日影 (阿俢)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)

## 谁在看这部电影 · · · · · ·

- ""
  2分钟前 看过
- 现在时间上午十
  6分钟前 想看
- 千层度
  8分钟前 看过

627481人看过 / 281156人想看

订阅小森林 夏秋篇的评论:
feed: rss 2.0